@@ -413,7 +413,7 @@ def do_use(project: Project, python: str, first: bool = False) -> None:
     old_path = project.config.get("python.path")
     new_path = python_path
     project.project_config["python.path"] = Path(new_path).as_posix()
-    if old_path and Path(old_path) != Path(new_path):
+    if old_path and Path(old_path) != Path(new_path) and not project.is_global:
         stream.echo(stream.cyan("Updating executable scripts..."))
         project.environment.update_shebangs(new_path)
 
@@ -429,6 +429,7 @@ def do_info(
     python_version = get_python_version(python_path, True)
     if not python and not show_project and not env:
         rows = [
+            (stream.cyan("PDM version:", bold=True), project.core.version),
             (
                 stream.cyan("Python Interpreter:", bold=True),
                 python_path + f" ({python_version})",
