@@ -2,6 +2,7 @@ import re
 from pathlib import Path
 
 import tomlkit
+import tomlkit.exceptions
 
 from pdm.formats.base import MetaConverter, convert_from
 from pdm.models.requirements import parse_requirement
@@ -9,7 +10,10 @@ from pdm.models.requirements import parse_requirement
 
 def check_fingerprint(project, filename):
     with open(filename, encoding="utf-8") as fp:
-        data = tomlkit.parse(fp.read())
+        try:
+            data = tomlkit.parse(fp.read())
+        except tomlkit.exceptions.TOMLKitError:
+            return False
 
     return "tool" in data and "flit" in data["tool"]
 
